defmodule Nulla.Activities.Activity do
  use Ecto.Schema
  import Ecto.Changeset
  alias Nulla.Snowflake
  alias Nulla.Types.StringOrJson

  @derive {Jason.Encoder, only: [:ap_id, :type, :actor, :object]}
  @primary_key {:id, :integer, autogenerate: false}
  schema "activities" do
    field :ap_id, :string
    field :type, :string
    field :actor, :string
    field :object, StringOrJson
    field :to, {:array, :string}
    field :cc, {:array, :string}

    timestamps(type: :utc_datetime)
  end

  @doc false
  def changeset(activity, attrs) do
    activity
    |> cast(attrs, [:ap_id, :type, :actor, :object, :to, :cc])
    |> maybe_put_id()
    |> validate_required([:ap_id, :type, :actor, :object])
  end

  defp maybe_put_id(changeset) do
    id = get_field(changeset, :id)

    if is_nil(id) do
      change(changeset, id: Snowflake.next_id())
    else
      changeset
    end
  end
end
